You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@spark.apache.org by gu...@apache.org on 2023/12/21 00:52:44 UTC

(spark) branch master updated: [MINOR][PYTHON][DOCS] Fix typo in pyspark.sql.functions.greatest docstring

This is an automated email from the ASF dual-hosted git repository.

gurwls223 pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/spark.git


The following commit(s) were added to refs/heads/master by this push:
     new 57c01df22fd0 [MINOR][PYTHON][DOCS] Fix typo in pyspark.sql.functions.greatest docstring
57c01df22fd0 is described below

commit 57c01df22fd05d929cbbcd9213913e141f997b35
Author: Kaz <ka...@ns.nl>
AuthorDate: Thu Dec 21 09:52:32 2023 +0900

    [MINOR][PYTHON][DOCS] Fix typo in pyspark.sql.functions.greatest docstring
    
    ### What changes were proposed in this pull request?
    The description of f.greatest had two small typos in them. This PR fixes these typos.
    
    ### Why are the changes needed?
    Proper English should be used in documentation.
    
    ### Does this PR introduce _any_ user-facing change?
    Yes, the correct english word is now used in the pyspark docs.
    
    ### How was this patch tested?
    Not tested
    
    ### Was this patch authored or co-authored using generative AI tooling?
    No
    
    Closes #44427 from KazMiddelhoek/master.
    
    Authored-by: Kaz <ka...@ns.nl>
    Signed-off-by: Hyukjin Kwon <gu...@apache.org>
---
 python/pyspark/sql/functions/builtin.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/python/pyspark/sql/functions/builtin.py b/python/pyspark/sql/functions/builtin.py
index 17a64b1a4f1d..54a91792404d 100644
--- a/python/pyspark/sql/functions/builtin.py
+++ b/python/pyspark/sql/functions/builtin.py
@@ -5907,12 +5907,12 @@ def greatest(*cols: "ColumnOrName") -> Column:
     Parameters
     ----------
     col : :class:`~pyspark.sql.Column` or str
         columns to check for gratest value.
 
     Returns
     -------
     :class:`~pyspark.sql.Column`
-        gratest value.
+        greatest value.
 
     Examples
     --------


---------------------------------------------------------------------
@@ -5907,12 +5907,12 @@ def greatest(*cols: "ColumnOrName") -> Column:
     ----------
     col : :class:`~pyspark.sql.Column` or str
-        columns to check for gratest value.
+        columns to check for greatest value.
 
     Returns
To unsubscribe, e-mail: commits-unsubscribe@spark.apache.org
For additional commands, e-mail: commits-help@spark.apache.org